import { EventMetadataV6, FunctionMetadataV6, ModuleConstantMetadataV6 } from '../../interfaces/metadata';
import { MetadataInterface } from '../types';
import Option from '../../codec/Option';
import Struct from '../../codec/Struct';
import Vec from '../../codec/Vec';
import Text from '../../primitive/Text';
import { StorageEntryMetadata } from './Storage';
/**
 * @name ModuleMetadataV6
 * @description
 * The definition of a module in the system
 */
export declare class ModuleMetadataV6 extends Struct {
    constructor(value?: any);
    /**
     * @description the module calls
     */
    readonly calls: Option<Vec<FunctionMetadataV6>>;
    /**
     * @description the module constants
     */
    readonly constants: Vec<ModuleConstantMetadataV6>;
    /**
     * @description the module events
     */
    readonly events: Option<Vec<EventMetadataV6>>;
    /**
     * @description the module name
     */
    readonly name: Text;
    /**
     * @description the module prefix
     */
    readonly prefix: Text;
    /**
     * @description the associated module storage
     */
    readonly storage: Option<Vec<StorageEntryMetadata>>;
}
/**
 * @name MetadataV6
 * @description
 * The runtime metadata as a decoded structure
 */
export default class MetadataV6 extends Struct implements MetadataInterface<ModuleMetadataV6> {
    constructor(value?: any);
    /**
     * @description The associated modules for this structure
     */
    readonly modules: Vec<ModuleMetadataV6>;
}
